@@ -85,7 +85,12 @@ err_free:
 	return PTR_ERR_OR_ZERO(dev);
 }
 
+/* EL9 kernel removed the callback that was returning void  */
+#if KERNEL_VERSION(6, 11, 0) <= LINUX_VERSION_CODE
+void evdi_platform_device_remove(struct platform_device *pdev)
+#else
 int evdi_platform_device_remove(struct platform_device *pdev)
+#endif
 {
 	struct evdi_platform_device_data *data = platform_get_drvdata(pdev);
 
@@ -93,7 +98,10 @@ int evdi_platform_device_remove(struct platform_device *pdev)
 
 	evdi_drm_device_remove(data->drm_dev);
 	kfree(data);
+#if KERNEL_VERSION(6, 11, 0) <= LINUX_VERSION_CODE
+#else
 	return 0;
+#endif
 }
 
 bool evdi_platform_device_is_free(struct platform_device *pdev)
