@@ -21,6 +21,7 @@
 #define _EVDI_PLATFORM_DEV_H_
 
 #include <linux/types.h>
+#include <linux/version.h>
 
 struct platform_device_info;
 struct platform_device;
@@ -31,7 +32,12 @@ struct platform_device *evdi_platform_dev_create(struct platform_device_info *in
 void evdi_platform_dev_destroy(struct platform_device *dev);
 
 int evdi_platform_device_probe(struct platform_device *pdev);
+/* EL9 kernel removed the callback that was returning void  */
+#if KERNEL_VERSION(6, 11, 0) <= LINUX_VERSION_CODE
+void evdi_platform_device_remove(struct platform_device *pdev);
+#else
 int evdi_platform_device_remove(struct platform_device *pdev);
+#endif
 bool evdi_platform_device_is_free(struct platform_device *pdev);
 void evdi_platform_device_link(struct platform_device *pdev,
 				struct device *parent);
